[GRASS-SVN] r50938 - in grass/trunk: db/drivers/mysql display/d.mon display/d.what.vect imagery/i.evapo.mh imagery/i.evapo.pt include include/defs lib/gpde lib/python/temporal lib/raster lib/vector/Vlib lib/vector/dglib/examples locale scripts/v.krige

svn_grass at osgeo.org svn_grass at osgeo.org
Sat Feb 25 08:21:05 EST 2012


Author: neteler
Date: 2012-02-25 05:21:05 -0800 (Sat, 25 Feb 2012)
New Revision: 50938

Modified:
   grass/trunk/db/drivers/mysql/grass-mesql.html
   grass/trunk/db/drivers/mysql/grass-mysql.html
   grass/trunk/display/d.mon/d.mon.html
   grass/trunk/display/d.what.vect/d.what.vect.html
   grass/trunk/imagery/i.evapo.mh/main.c
   grass/trunk/imagery/i.evapo.pt/main.c
   grass/trunk/include/defs/vector.h
   grass/trunk/include/gis.h
   grass/trunk/lib/gpde/N_pde.h
   grass/trunk/lib/gpde/gpdelib.dox
   grass/trunk/lib/python/temporal/abstract_map_dataset.py
   grass/trunk/lib/python/temporal/abstract_space_time_dataset.py
   grass/trunk/lib/python/temporal/space_time_datasets.py
   grass/trunk/lib/raster/get_row_colr.c
   grass/trunk/lib/raster/rasterlib.dox
   grass/trunk/lib/vector/Vlib/break_polygons.c
   grass/trunk/lib/vector/dglib/examples/rtest01.sh
   grass/trunk/locale/README
   grass/trunk/scripts/v.krige/v.krige.py
Log:
typos fixed, part 2 (bug trac #1591)

Modified: grass/trunk/db/drivers/mysql/grass-mesql.html
===================================================================
--- grass/trunk/db/drivers/mysql/grass-mesql.html	2012-02-25 13:14:51 UTC (rev 50937)
+++ grass/trunk/db/drivers/mysql/grass-mesql.html	2012-02-25 13:21:05 UTC (rev 50938)
@@ -40,7 +40,7 @@
 </pre>
 
 <h2>Data types, indexes</h2>
-For more informations about supported data types and indexes
+For more information about supported data types and indexes
 see the documentation for 
 <a href="grass-mysql.html">MySQL (mysql) driver</a>
 

Modified: grass/trunk/db/drivers/mysql/grass-mysql.html
===================================================================
--- grass/trunk/db/drivers/mysql/grass-mysql.html	2012-02-25 13:14:51 UTC (rev 50937)
+++ grass/trunk/db/drivers/mysql/grass-mysql.html	2012-02-25 13:21:05 UTC (rev 50938)
@@ -16,7 +16,7 @@
 attributes in MySQL server.
 <p>
 Because vector attribute tables 
-are created automaticaly when a new vector is written and the 
+are created automatically when a new vector is written and the 
 name of the table is the same as the name of the vector it is 
 good practice to create a new database for each GRASS mapset.
 
@@ -72,7 +72,7 @@
 </ul>
 
 <h2>Indexes</h2>
-GRASS modules automaticaly create index on key column of vector
+GRASS modules automatically create index on key column of vector
 attributes table. The index on key column is important 
 for performance of modules which update the attribute table,
 for example v.to.db, v.distance and v.what.rast.
@@ -80,7 +80,7 @@
 <h2>Privileges</h2>
 Because MySQL does not support groups of users and because 
 only MySQL 'root' can grant privileges to other users
-GRASS cannot automaticaly grant select privileges on created
+GRASS cannot automatically grant select privileges on created
 tables to group of users.
 <p>
 If you want to give privilege to read data from your mapset 

Modified: grass/trunk/display/d.mon/d.mon.html
===================================================================
--- grass/trunk/display/d.mon/d.mon.html	2012-02-25 13:14:51 UTC (rev 50937)
+++ grass/trunk/display/d.mon/d.mon.html	2012-02-25 13:21:05 UTC (rev 50938)
@@ -17,7 +17,7 @@
 <p>When a monitor is <em>started</em>, it is therefore also
 (automatically) <em>selected</em> for output, unless the
 <b>-s</b> flag is set by the user; the user can also
-explictly <b>select</b> a monitor that has been started.
+explicitly <b>select</b> a monitor that has been started.
 
 <p>The desired monitor should be started once and need not be restarted
 unless it is stopped for some reason. A monitor may continue to run
@@ -38,7 +38,7 @@
 sets the <b>-s</b> flag.  In order to use (direct graphics output to)
 a monitor, the user must <em>select</em> that monitor for use, either
 by simply starting the monitor without the <b>-s</b> flag or by
-explictly selecting the monitor for output. Only running monitors can
+explicitly selecting the monitor for output. Only running monitors can
 be selected for graphics output.
 
 <p>The user can run multiple graphics monitors by simply starting each of

Modified: grass/trunk/display/d.what.vect/d.what.vect.html
===================================================================
--- grass/trunk/display/d.what.vect/d.what.vect.html	2012-02-25 13:14:51 UTC (rev 50937)
+++ grass/trunk/display/d.what.vect/d.what.vect.html	2012-02-25 13:21:05 UTC (rev 50938)
@@ -9,7 +9,7 @@
 within the current geographic region in the active display frame on the 
 graphic monitor. Query results from map(s) are by default displayed in a new 
 monitor, where label values can be added or changed. Using parameter <b>-x</b> 
-informations will be displayed as plain text to terminal window.
+information will be displayed as plain text to terminal window.
 <p>This module always reports standard acres, even when the location uses
 US Survey feet as the map unit.
 

Modified: grass/trunk/imagery/i.evapo.mh/main.c
===================================================================
--- grass/trunk/imagery/i.evapo.mh/main.c	2012-02-25 13:14:51 UTC (rev 50937)
+++ grass/trunk/imagery/i.evapo.mh/main.c	2012-02-25 13:21:05 UTC (rev 50938)
@@ -48,7 +48,7 @@
     DCELL d_tempkavg, d_tempkmin, d_tempkmax, d_rnet, d_p;
     DCELL d_daily_et;
 
-    /* region informations and handler */
+    /* region information and handler */
     struct Cell_head cellhd;
     int nrows, ncols;
     int row, col;

Modified: grass/trunk/imagery/i.evapo.pt/main.c
===================================================================
--- grass/trunk/imagery/i.evapo.pt/main.c	2012-02-25 13:14:51 UTC (rev 50937)
+++ grass/trunk/imagery/i.evapo.pt/main.c	2012-02-25 13:21:05 UTC (rev 50938)
@@ -45,7 +45,7 @@
     DCELL d_tempka, d_pt_patm, d_rnet, d_g0;
     DCELL d_pt_alpha, d_pt_delta, d_pt_ghamma, d_daily_et;
 
-    /* region informations and handler */
+    /* region information and handler */
     struct Cell_head cellhd;
     int nrows, ncols;
     int row, col;

Modified: grass/trunk/include/defs/vector.h
===================================================================
--- grass/trunk/include/defs/vector.h	2012-02-25 13:14:51 UTC (rev 50937)
+++ grass/trunk/include/defs/vector.h	2012-02-25 13:21:05 UTC (rev 50938)
@@ -189,7 +189,7 @@
 int Vect_get_constraint_box(const struct Map_info *, struct bound_box *);
 
 
-/* Get map level 2 informations */
+/* Get map level 2 information */
 int Vect_level(const struct Map_info *);
 int Vect_get_line_type(const struct Map_info *, int);
 plus_t Vect_get_num_nodes(const struct Map_info *);

Modified: grass/trunk/include/gis.h
===================================================================
--- grass/trunk/include/gis.h	2012-02-25 13:14:51 UTC (rev 50937)
+++ grass/trunk/include/gis.h	2012-02-25 13:21:05 UTC (rev 50938)
@@ -420,7 +420,7 @@
     const char **keywords;	/* Keywords describing module */
     /* further items are possible: author(s), version */
     int overwrite;		/* overwrite old files */
-    int verbose;		/* print all informations about progress and so on */
+    int verbose;		/* print all information about progress and so on */
 };
 
 struct TimeStamp

Modified: grass/trunk/lib/gpde/N_pde.h
===================================================================
--- grass/trunk/lib/gpde/N_pde.h	2012-02-25 13:14:51 UTC (rev 50937)
+++ grass/trunk/lib/gpde/N_pde.h	2012-02-25 13:21:05 UTC (rev 50938)
@@ -98,7 +98,7 @@
 /* *************************************************************** */
 
 /*!
- * \brief Geometric informations about the structured grid
+ * \brief Geometric information about the structured grid
  * */
 typedef struct
 {

Modified: grass/trunk/lib/gpde/gpdelib.dox
===================================================================
--- grass/trunk/lib/gpde/gpdelib.dox	2012-02-25 13:14:51 UTC (rev 50937)
+++ grass/trunk/lib/gpde/gpdelib.dox	2012-02-25 13:21:05 UTC (rev 50938)
@@ -21,7 +21,7 @@
 and a computer with at least two cores or cpu's.
 Most proprietary compilers support OpenMP. 
 The free gnu-C compiler supports OpenMP since version 4.2.
-More informations about OpenMP are available at http://www.openmp.org .
+More information about OpenMP are available at http://www.openmp.org .
 <br>
 <br>
 Based on the finite volume discretization for structured grids, 
@@ -517,7 +517,7 @@
 
 
 \verbatim
-Geometric informations about the structured grid is stored in this structure
+Geometric information about the structured grid is stored in this structure
 
 typedef struct
 {

Modified: grass/trunk/lib/python/temporal/abstract_map_dataset.py
===================================================================
--- grass/trunk/lib/python/temporal/abstract_map_dataset.py	2012-02-25 13:14:51 UTC (rev 50937)
+++ grass/trunk/lib/python/temporal/abstract_map_dataset.py	2012-02-25 13:21:05 UTC (rev 50938)
@@ -371,7 +371,7 @@
 
         if self.is_in_db(dbif):
  
-            # SELECT all needed informations from the database
+            # SELECT all needed information from the database
             self.select(dbif)
            
             # First we unregister from all dependent space time datasets

Modified: grass/trunk/lib/python/temporal/abstract_space_time_dataset.py
===================================================================
--- grass/trunk/lib/python/temporal/space_time_datasets.py	2012-02-25 13:14:51 UTC (rev 50937)
+++ grass/trunk/lib/python/temporal/space_time_datasets.py	2012-02-25 13:21:05 UTC (rev 50938)
@@ -36,7 +36,7 @@
     """Raster dataset class
 
        This class provides functions to select, update, insert or delete raster
-       map informations and valid time stamps into the SQL temporal database.
+       map information and valid time stamps into the SQL temporal database.
     """
     def __init__(self, ident):
 	self.reset(ident)
@@ -114,7 +114,7 @@
     """Raster3d dataset class
 
        This class provides functions to select, update, insert or delete raster3d
-       map informations and valid time stamps into the SQL temporal database.
+       map information and valid time stamps into the SQL temporal database.
     """
     def __init__(self, ident):
 	self.reset(ident)
@@ -196,7 +196,7 @@
     """Vector dataset class
 
        This class provides functions to select, update, insert or delete vector
-       map informations and valid time stamps into the SQL temporal database.
+       map information and valid time stamps into the SQL temporal database.
     """
     def __init__(self, ident):
 	self.reset(ident)

Modified: grass/trunk/lib/raster/get_row_colr.c
===================================================================
--- grass/trunk/lib/raster/get_row_colr.c	2012-02-25 13:14:51 UTC (rev 50937)
+++ grass/trunk/lib/raster/get_row_colr.c	2012-02-25 13:21:05 UTC (rev 50938)
@@ -23,7 +23,7 @@
  * Reads a row of raster data and converts it to red, green and blue
  * components according to the <em>colors</em> parameter. This
  * provides a convenient way to treat a raster layer as a color image
- * without having to explictly cater for each of <tt>CELL</tt>,
+ * without having to explicitly cater for each of <tt>CELL</tt>,
  * <tt>FCELL</tt> and <tt>DCELL</tt> types.
  *
  *  \param fd field descriptor

Modified: grass/trunk/lib/raster/rasterlib.dox
===================================================================
--- grass/trunk/lib/raster/rasterlib.dox	2012-02-25 13:14:51 UTC (rev 50937)
+++ grass/trunk/lib/raster/rasterlib.dox	2012-02-25 13:21:05 UTC (rev 50938)
@@ -1297,7 +1297,7 @@
 components according to the colors.
 
 This provides a convenient way to treat a raster layer as a color
-image without having to explictly cater for each of CELL, FCELL and
+image without having to explicitly cater for each of CELL, FCELL and
 DCELL types.
 
 \section Upgraded_color_functions Upgraded color functions

Modified: grass/trunk/lib/vector/Vlib/break_polygons.c
===================================================================
--- grass/trunk/lib/vector/Vlib/break_polygons.c	2012-02-25 13:14:51 UTC (rev 50937)
+++ grass/trunk/lib/vector/Vlib/break_polygons.c	2012-02-25 13:21:05 UTC (rev 50938)
@@ -57,7 +57,7 @@
     double a1, a2;		/* angles */
     char cross;			/* 0 - do not break, 1 - break */
     char used;			/* 0 - was not used to break line, 1 - was used to break line
-				 *   this is stored because points are automaticaly marked as cross, even if not used 
+				 *   this is stored because points are automatically marked as cross, even if not used 
 				 *   later to break lines */
 } XPNT;
 
@@ -66,7 +66,7 @@
     double a1, a2;		/* angles */
     char cross;			/* 0 - do not break, 1 - break */
     char used;			/* 0 - was not used to break line, 1 - was used to break line
-				 *   this is stored because points are automaticaly marked as cross, even if not used 
+				 *   this is stored because points are automatically marked as cross, even if not used 
 				 *   later to break lines */
 } XPNT2;
 

Modified: grass/trunk/lib/vector/dglib/examples/rtest01.sh
===================================================================
--- grass/trunk/lib/vector/dglib/examples/rtest01.sh	2012-02-25 13:14:51 UTC (rev 50937)
+++ grass/trunk/lib/vector/dglib/examples/rtest01.sh	2012-02-25 13:21:05 UTC (rev 50938)
@@ -5,7 +5,7 @@
 # asserting that the input graph to ./unflatten be identical to its
 # output.
 # There are a number of implicit tests here:
-# - When a graph is unflattened all informations kept in the buffers
+# - When a graph is unflattened all information kept in the buffers
 #   are moved to an avl-tree using gnGrpAddLink(). Link insertions
 #   identical to those made by a user program are performed.
 #   Before returning gnGrpUnflatten() destroys the buffers.

Modified: grass/trunk/locale/README
===================================================================
--- grass/trunk/locale/README	2012-02-25 13:14:51 UTC (rev 50937)
+++ grass/trunk/locale/README	2012-02-25 13:21:05 UTC (rev 50938)
@@ -22,7 +22,7 @@
  G_message ( _("..."), ...);
 
 Careful:
-  G_message should be used for messages - informations about
+  G_message should be used for messages - information about
   the process for user while fprintf(stdout...) for data output.
   G_message output is not expected to be send to pipe or file.
   fprintf(stdout...) output is usually send to pipe or file.

Modified: grass/trunk/scripts/v.krige/v.krige.py
===================================================================
--- grass/trunk/scripts/v.krige/v.krige.py	2012-02-25 13:14:51 UTC (rev 50937)
+++ grass/trunk/scripts/v.krige/v.krige.py	2012-02-25 13:21:05 UTC (rev 50938)
@@ -15,7 +15,7 @@
 for details.
 """
 
-## g.parser informations
+## g.parser information
 
 #%module
 #% description: Performs ordinary or block kriging for vector maps.



More information about the grass-commit mailing list
--- grass/trunk/lib/python/temporal/abstract_space_time_dataset.py	2012-02-25 13:14:51 UTC (rev 50937)
+++ grass/trunk/lib/python/temporal/abstract_space_time_dataset.py	2012-02-25 13:21:05 UTC (rev 50938)
@@ -427,7 +427,7 @@
            Gaps between maps are identified as unregistered maps with id==None.
 
            The map objects are initialized with the id and the temporal extent of the granule (temporal type, start time, end time).
-           In case more map informations are needed, use the select() method for each listed object.
+           In case more map information are needed, use the select() method for each listed object.
 
            @param stds: The space time dataset to be used for temporal sampling
            @param method: This option specifies what sample method should be used. In case the registered maps are of temporal point type,
@@ -574,7 +574,7 @@
            Gaps between maps are identified as unregistered maps with id==None.
 
            The objects are initialized with the id and the temporal extent (temporal type, start time, end time).
-           In case more map informations are needed, use the select() method for each listed object.
+           In case more map information are needed, use the select() method for each listed object.
 
            @param gran: The granularity to be used 
            @param dbif: The database interface to be used
@@ -638,7 +638,7 @@
            Gaps between maps are identified as maps with id==None
 
            The objects are initialized with the id and the temporal extent (temporal type, start time, end time).
-           In case more map informations are needed, use the select() method for each listed object.
+           In case more map information are needed, use the select() method for each listed object.
 
            @param where: The SQL where statement to select a subset of the registered maps without "WHERE"
            @param dbif: The database interface to be used
@@ -689,7 +689,7 @@
         """Return all registered maps as ordered object list for temporal topological operations
 
            The objects are initialized with the id and the temporal extent (temporal type, start time, end time).
-           In case more map informations are needed, use the select() method for each listed object.
+           In case more map information are needed, use the select() method for each listed object.
 
            @param where: The SQL where statement to select a subset of the registered maps without "WHERE"
            @param order: The SQL order statement to be used to order the objects in the list without "ORDER BY"
@@ -800,7 +800,7 @@
             dbif.connect()
             connect = True
 
         # SELECT all needed informations from the database
         self.select(dbif)
 
         core.verbose(_("Drop map register table: %s") %  (self.get_map_register()))
@@ -800,7 +800,7 @@
             connect = True
 
-        # SELECT all needed informations from the database
+        # SELECT all needed information from the database
         self.select(dbif)
 

Modified: grass/trunk/lib/python/temporal/space_time_datasets.py
===================================================================